==> lawn_0.3.0.tar.gz: lawn/R/defunct-deprecated.R <==
#' Expand a bounding box
#'
#' This function is defunct
#'
#' @keywords internal
lawn_size <- function(...) {
  .Defunct(msg = "lawn_size is defunct - it has been removed from turf.js")
}

#' Reclassify properties data
#'
#' This function is defunct
#'
#' @keywords internal
lawn_reclass <- function(...) {
  .Defunct(msg = "lawn_reclass is defunct - it has been removed from turf.js")
}

#' Get Jenks breaks
#'
#' This function is defunct
#'
#' @keywords internal
lawn_jenks <- function(...) {
  .Defunct(msg = "lawn_jenks is defunct - it has been removed from turf.js")
}

#' Calculate quantiles
#'
#' This function is defunct
#'
#' @keywords internal
lawn_quantile <- function(...) {
  .Defunct(msg = "lawn_quantile is defunct - it has been removed from turf.js")
}

#' Calculate a series of aggregations for a set of points within polygons
#'
#' This function is defunct
#'
#' @keywords internal
lawn_aggregate <- function(...) {
  .Defunct(msg = "lawn_aggregate is defunct - it has been removed from turf.js")
}


#' Defunct functions in \pkg{lawn}
#'
#' \itemize{
#'  \item \code{\link{lawn_size}}: Function removed. The \code{size}
#'  method in turf.js has been removed.
#'  See \url{https://github.com/Turfjs/turf/issues/306}
#'  \item \code{\link{lawn_reclass}}: Function removed. The \code{reclass}
#'  method in turf.js has been removed.
#'  See \url{https://github.com/Turfjs/turf/issues/306}
#'  \item \code{\link{lawn_jenks}}: Function removed. The \code{jenks}
#'  method in turf.js has been removed.
#'  See \url{https://github.com/Turfjs/turf/issues/306}
#'  \item \code{\link{lawn_quantile}}: Function removed. The \code{quantile}
#'  method in turf.js has been removed.
#'  See \url{https://github.com/Turfjs/turf/issues/306}
#'  \item \code{\link{lawn_aggregate}}: Function removed. The \code{aggregate}
#'  method in turf.js has been removed.
#'  See \url{https://github.com/Turfjs/turf/issues/306}
#' }
#'
#' @name lawn-defunct
NULL

==> lawn_0.4.2.tar.gz: lawn/R/defunct-deprecated.R <==
#' Expand a bounding box
#'
#' This function is defunct
#'
#' @keywords internal
lawn_size <- function(...) {
  .Defunct(msg = "lawn_size is defunct - it has been removed from turf.js")
}

#' Reclassify properties data
#'
#' This function is defunct
#'
#' @keywords internal
lawn_reclass <- function(...) {
  .Defunct(msg = "lawn_reclass is defunct - it has been removed from turf.js")
}

#' Get Jenks breaks
#'
#' This function is defunct
#'
#' @keywords internal
lawn_jenks <- function(...) {
  .Defunct(msg = "lawn_jenks is defunct - it has been removed from turf.js")
}

#' Calculate quantiles
#'
#' This function is defunct
#'
#' @keywords internal
lawn_quantile <- function(...) {
  .Defunct(msg = "lawn_quantile is defunct - it has been removed from turf.js")
}

#' Calculate a series of aggregations for a set of points within polygons
#'
#' This function is defunct
#'
#' @keywords internal
lawn_aggregate <- function(...) {
  .Defunct(msg = "lawn_aggregate is defunct - it has been removed from turf.js")
}


#' Defunct functions in \pkg{lawn}
#'
#' \itemize{
#'  \item [lawn_size]: Function removed. The `size`
#'  method in turf.js has been removed.
#'  See <https://github.com/Turfjs/turf/issues/306>
#'  \item [lawn_reclass]: Function removed. The `reclass`
#'  method in turf.js has been removed.
#'  See <https://github.com/Turfjs/turf/issues/306>
#'  \item [lawn_jenks]: Function removed. The `jenks`
#'  method in turf.js has been removed.
#'  See <https://github.com/Turfjs/turf/issues/306>
#'  \item [lawn_quantile]: Function removed. The `quantile`
#'  method in turf.js has been removed.
#'  See <https://github.com/Turfjs/turf/issues/306>
#'  \item [lawn_aggregate]: Function removed. The `aggregate`
#'  method in turf.js has been removed.
#'  See <https://github.com/Turfjs/turf/issues/306>
#' }
#'
#' @name lawn-defunct
NULL
